==> kubernetes-model-gatewayapi-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRouteListFluent<A extends HTTPRouteListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,HTTPRoute item);
  public A setToItems(Integer index,HTTPRoute item);
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRoute... items);
  public A addAllToItems(Collection<HTTPRoute> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRoute... items);
  public A removeAllFromItems(Collection<HTTPRoute> items);
  public A removeMatchingFromItems(Predicate<HTTPRouteBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRoute> getItems();
  public List<HTTPRoute> buildItems();
  public HTTPRoute buildItem(Integer index);
  public HTTPRoute buildFirstItem();
  public HTTPRoute buildLastItem();
  public HTTPRoute buildMatchingItem(Predicate<HTTPRouteBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<HTTPRouteBuilder> predicate);
  public A withItems(List<HTTPRoute> items);
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRoute... items);
  public Boolean hasItems();
  public HTTPRouteListFluent.ItemsNested<A> addNewItem();
  public HTTPRouteListFluent.ItemsNested<A> addNewItemLike(HTTPRoute item);
  public HTTPRouteListFluent.ItemsNested<A> setNewItemLike(Integer index,HTTPRoute item);
  public HTTPRouteListFluent.ItemsNested<A> editItem(Integer index);
  public HTTPRouteListFluent.ItemsNested<A> editFirstItem();
  public HTTPRouteListFluent.ItemsNested<A> editLastItem();
  public HTTPRouteListFluent.ItemsNested<A> editMatchingItem(Predicate<HTTPRouteBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,HTTPRouteFluent<HTTPRouteListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRouteListFluent<A extends HTTPRouteListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,HTTPRoute item);
  public A setToItems(int index,HTTPRoute item);
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRoute... items);
  public A addAllToItems(Collection<HTTPRoute> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRoute... items);
  public A removeAllFromItems(Collection<HTTPRoute> items);
  public A removeMatchingFromItems(Predicate<HTTPRouteBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRoute> getItems();
  public List<HTTPRoute> buildItems();
  public HTTPRoute buildItem(int index);
  public HTTPRoute buildFirstItem();
  public HTTPRoute buildLastItem();
  public HTTPRoute buildMatchingItem(Predicate<HTTPRouteBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<HTTPRouteBuilder> predicate);
  public A withItems(List<HTTPRoute> items);
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRoute... items);
  public Boolean hasItems();
  public HTTPRouteListFluent.ItemsNested<A> addNewItem();
  public HTTPRouteListFluent.ItemsNested<A> addNewItemLike(HTTPRoute item);
  public HTTPRouteListFluent.ItemsNested<A> setNewItemLike(int index,HTTPRoute item);
  public HTTPRouteListFluent.ItemsNested<A> editItem(int index);
  public HTTPRouteListFluent.ItemsNested<A> editFirstItem();
  public HTTPRouteListFluent.ItemsNested<A> editLastItem();
  public HTTPRouteListFluent.ItemsNested<A> editMatchingItem(Predicate<HTTPRouteBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,HTTPRouteFluent<HTTPRouteListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
